@@ -684,21 +684,23 @@ class LogicAppPipelineConfigManager:
         # BlobStorageManager object is created from the connectionstring coming from config object.
         self.blobManager = BlobStorageManager(config.BLOB_STORAGE_CONNECTION_STRING)
         # declaration of file name that will contain the endpoint that has just been published.
-        self.REMOTE_FILE_NAME = "published_pipeline.json"
+        #self.REMOTE_FILE_NAME = "published_pipeline.json"
         # declaration of container (or folder) which will contain the json file
         self.BLOB_CONTAINER = "{0}/configs".format(config.CONTAINER_NAME)
         #http link where the json file will be deposited
-        self.file_url = "https://humlstorage.blob.core.windows.net/{0}/{1}".format(self.BLOB_CONTAINER,self.REMOTE_FILE_NAME)
+        #self.file_url = "https://humlstorage.blob.core.windows.net/{0}/{1}".format(self.BLOB_CONTAINER,self.REMOTE_FILE_NAME)
     
-    def update(self, pipelineid, pipeline_endpoint):
+    def update(self, pipelineid, pipeline_endpoint, pipeline_file_name):
         """ Create or update json file of the pipeline in the blob storage
 
         Arguments:
             pipelineid {str} -- pipeline id published
             pipeline_endpoint {str} --endpoint : http address through which the pipeline can be called
         """
-            
-        data = self.blobManager.download_json_by_url(self.file_url)
+        
+        file_url = "https://humlstorage.blob.core.windows.net/{0}/{1}".format(self.BLOB_CONTAINER, pipeline_file_name)
+
+        data = self.blobManager.download_json_by_url(file_url)
 
         data["pipelineid"] = pipelineid
         data["published_pipeline_endpoint"] = pipeline_endpoint
@@ -1248,6 +1250,19 @@ class ConfigHandler:
             configGen.by_args(sys.argv, config_path)
 
 
+class PipelineEndpointLauncher:
+    def start(self, ws, svc_pr, endpoint_pipeline, experiment_name, json_data):
+        """The PIPELINE_ENDPOINT pipeline is launched through its published REST address.
+        """
+        #workspaceProvider = WorkspaceProvider(self.config)
+        #ws,svc_pr = workspaceProvider.get_ws()
+        auth_header = svc_pr.get_authentication_header()
+        pipeline_endpoint_by_name = PipelineEndpoint.get(workspace=ws, name=endpoint_pipeline)
+        rest_endpoint = pipeline_endpoint_by_name.endpoint
+        print("pipeline_endpoint_by_name.endpoint : ", rest_endpoint)
+        _ = requests.post(rest_endpoint, headers=auth_header, json=json_data)
+
+
 
 class LazyFileDataDumper:
     def __init__(self,featuresHandler,feature_index):
